Struct aw_soc::gpio::Pin

source ·
pub struct Pin<A: BaseAddress, const P: char, const N: u8, M> { /* private fields */ }
Individual GPIO pin.

Implementations

source

impl<A: BaseAddress, const P: char, const N: u8, M: PinMode> Pin<A, P, N, M>

source

pub fn into_disabled(self) -> Pin<A, P, N, Disabled>

Disables the pin.

source

pub fn into_input(self) -> Pin<A, P, N, Input>

Configures the pin to operate as an input pin.

source

pub fn into_output(self) -> Pin<A, P, N, Output>

Configures the pin to operate as an output pin.

source

pub fn into_eint(self) -> Pin<A, P, N, EintMode>

Configures the pin to operate as an external interrupt.

source

pub fn into_function<const F: u8>(self) -> Pin<A, P, N, Function<F>>

Configures the pin to operate as an alternate function.