pub struct Serial<A: BaseAddress, const I: usize, PINS: Pins<I>> { /* private fields */ }
Managed serial structure with peripheral and pins.
Create a serial instance.
Close uart and release peripheral.
Writes a slice, blocking until everything has been written
Read more
Block until the serial interface has sent all buffered words
Writes a single word to the serial interface
Ensures that none of the previously written words are still buffered
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.